@@ -2,9 +2,10 @@ import os.path
 from nib import yaml
 
 class Document(dict):
-    def __init__(self, path=None, group=None, content=None, short=None, **kwargs):
+    def __init__(self, path=None, uri=None, group=None, content=None, short=None, **kwargs):
         dict.__init__(self, **kwargs)
         self.path, self.extension = os.path.splitext(path)
+        self.uri = uri
         self.group = group
         self.content = content
         self.short = short or content
@@ -14,22 +15,22 @@ class Document(dict):
                                                dict.__repr__(self))
 
     @classmethod
-    def from_file(cls, path, defaults=None):
+    def from_file(cls, path, options=None):
         metadata, sections = yaml.load(path, supplement=True)
-        group = metadata.setdefault('type', None)
+        group = metadata.setdefault('group', None)
 
-        if isinstance(defaults, dict):
+        if options:
+            path = os.path.relpath(path, options['document_path'])
+            defaults = options['defaults']
             for key in defaults:
                 metadata.setdefault(key, defaults[key])
 
         content = sections.pop(0)
-        short = None
+        short = content
         if len(sections):
-            short = content
             content += sections.pop(0)
 
         return Document(path=path,
-                        group=group,
                         content=content,
                         short=short,
                         **metadata
